#[non_exhaustive]pub enum ConfigError {
Read {
path: PathBuf,
message: String,
},
Parse {
message: String,
},
ZeroSamples,
ZeroVotes,
}Expand description
Why a configuration could not be loaded or run.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Read
The file could not be read.
Parse
The document is not a configuration this crate understands.
ZeroSamples
samples_per_item is zero.
ZeroVotes
votes_per_sample is zero.