#[non_exhaustive]pub enum BlockKind {
Answer,
Transition,
Receipt,
Notice,
Interaction,
Artifact,
Other,
}Expand description
The kinds of response block, as an item file names them (spec 18.1).
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Answer
Model-authored answer.
Transition
Model-authored transition.
Receipt
Server-authored receipt.
Notice
Server-authored notice.
Interaction
A persisted card.
Artifact
An artifact.
Other
A block this crate does not know about yet, so a core addition does not silently read as one of the above.
Implementations