#[non_exhaustive]pub enum OutcomeExpectation {
Succeeds,
Fails,
FailsWith(String),
}Expand description
Whether the turn is expected to complete.
A crashed turn satisfies “no command was journaled” for the wrong reason, so the default is that a turn must succeed and an item that means otherwise has to say so.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Succeeds
The orchestrator must return an assistant turn.
Fails
The orchestrator must fail, with any error.
FailsWith(String)
The orchestrator must fail with this stable error code.