#[non_exhaustive]pub enum ResolutionKind {
Exact,
Ambiguous,
Missing,
Unauthorized,
Stale,
}Expand description
The resolutions of TargetResolution,
as an item file names them.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Exact
Exactly one authorized case.
Ambiguous
Several authorized cases; the runtime must never pick one (I8).
Missing
The token was issued this turn but the case is gone.
Unknown token, or another tenant’s.
Stale
The case moved past the revision the token was issued at.
Implementations