pub struct WorkflowStateExpectation {
pub workflow: WorkflowKey,
pub path: String,
pub equals: Value,
pub ignore_case: bool,
}Expand description
A value some case of a workflow must hold at the end.
Fields
workflow: WorkflowKeyThe workflow.
path: StringJSON Pointer into a case’s state.
equals: ValueThe value that path must hold in at least one case.
ignore_case: boolCompare strings without regard to case.