pub struct CategoryStats {
pub samples: usize,
pub failing_samples: usize,
pub failures: usize,
}Expand description
Samples counted for one category.
Fields
samples: usizeTotal samples in the run.
failing_samples: usizeSamples with at least one failure in this category.
failures: usizeIndividual failures in this category.
Implementations
Sourceimpl CategoryStats
impl CategoryStats
Sourcepub fn failure_rate(&self) -> f64
pub fn failure_rate(&self) -> f64
Fraction of samples with at least one failure in this category.