#[non_exhaustive]pub enum HarnessError {
Setup {
message: String,
},
UnknownWorkflow {
workflow: String,
},
NoBlockingCard {
case: String,
},
Store {
message: String,
},
}Expand description
Why a sample could not be set up or started.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Setup
The world could not be built.
UnknownWorkflow
The item names a workflow the harness did not register.
NoBlockingCard
The item answers a card, and the case has none.
Store
The card store could not be read.
Implementations