pub enum UserMove {
Say {
text: String,
},
Press {
option: String,
},
Done,
}Expand description
What the person does next.
Variants
Say
Types a message.
Press
Presses an option of a card on screen, by the option’s id.
Done
Stops: the goal is reached as far as they can tell, or they give up.
Implementations