pub struct ModelUser { /* private fields */ }Expand description
A person played by a model.
Implementations
Sourceimpl ModelUser
impl ModelUser
Sourcepub fn new(provider: Arc<dyn ModelProvider>) -> Self
pub fn new(provider: Arc<dyn ModelProvider>) -> Self
A person played by provider, which should not be the one under test.
Sourcepub const fn with_temperature(self, temperature: f32) -> Self
pub const fn with_temperature(self, temperature: f32) -> Self
Plays at temperature, for a model that takes one.